# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.policy_agent_api import PolicyAgentApi  # noqa: E501
from stackl_client.rest import ApiException


class TestPolicyAgentApi(unittest.TestCase):
    """PolicyAgentApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.policy_agent_api.PolicyAgentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_data(self):
        """Test case for delete_data

        Delete Data  # noqa: E501
        """
        pass

    def test_delete_policy(self):
        """Test case for delete_policy

        Delete Policy  # noqa: E501
        """
        pass

    def test_get_agent_policies(self):
        """Test case for get_agent_policies

        Get Agent Policies  # noqa: E501
        """
        pass

    def test_get_data(self):
        """Test case for get_data

        Get Data  # noqa: E501
        """
        pass

    def test_get_sat_data_from_sat(self):
        """Test case for get_sat_data_from_sat

        Get Sat Data From Sat  # noqa: E501
        """
        pass

    def test_get_sat_policies_from_sat(self):
        """Test case for get_sat_policies_from_sat

        Get Sat Policies From Sat  # noqa: E501
        """
        pass

    def test_get_sit_data_from_sit(self):
        """Test case for get_sit_data_from_sit

        Get Sit Data From Sit  # noqa: E501
        """
        pass

    def test_get_sit_policies_from_sit(self):
        """Test case for get_sit_policies_from_sit

        Get Sit Policies From Sit  # noqa: E501
        """
        pass

    def test_put_data(self):
        """Test case for put_data

        Put Data  # noqa: E501
        """
        pass

    def test_put_sat_policies(self):
        """Test case for put_sat_policies

        Put Sat Policies  # noqa: E501
        """
        pass

    def test_put_sit_policies(self):
        """Test case for put_sit_policies

        Put Sit Policies  # noqa: E501
        """
        pass

    def test_run_query_for_sit_and_sat(self):
        """Test case for run_query_for_sit_and_sat

        Run Query For Sit And Sat  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
