# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.functional_requirements_api import FunctionalRequirementsApi  # noqa: E501
from stackl_client.rest import ApiException


class TestFunctionalRequirementsApi(unittest.TestCase):
    """FunctionalRequirementsApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.functional_requirements_api.FunctionalRequirementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_functional_requirement(self):
        """Test case for delete_functional_requirement

        Delete Functional Requirement  # noqa: E501
        """
        pass

    def test_get_functional_requirement_by_name(self):
        """Test case for get_functional_requirement_by_name

        Get Functional Requirement By Name  # noqa: E501
        """
        pass

    def test_get_functional_requirements(self):
        """Test case for get_functional_requirements

        Get Functional Requirements  # noqa: E501
        """
        pass

    def test_post_functional_requirement(self):
        """Test case for post_functional_requirement

        Post Functional Requirement  # noqa: E501
        """
        pass

    def test_put_functional_requirement(self):
        """Test case for put_functional_requirement

        Put Functional Requirement  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
