# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.policy_templates_api import PolicyTemplatesApi  # noqa: E501
from stackl_client.rest import ApiException


class TestPolicyTemplatesApi(unittest.TestCase):
    """PolicyTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.policy_templates_api.PolicyTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_policy_template_by_name(self):
        """Test case for get_policy_template_by_name

        Get Policy Template By Name  # noqa: E501
        """
        pass

    def test_get_policy_templates(self):
        """Test case for get_policy_templates

        Get Policy Templates  # noqa: E501
        """
        pass

    def test_put_policy_template(self):
        """Test case for put_policy_template

        Put Policy Template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
