# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import stackl_client
from stackl_client.models.stack_application_template import StackApplicationTemplate  # noqa: E501
from stackl_client.rest import ApiException

class TestStackApplicationTemplate(unittest.TestCase):
    """StackApplicationTemplate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StackApplicationTemplate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = stackl_client.models.stack_application_template.StackApplicationTemplate()  # noqa: E501
        if include_optional :
            return StackApplicationTemplate(
                name = '0', 
                description = '0', 
                services = [
                    '0'
                    ], 
                extra_functional_requirements = stackl_client.models.extra_functional_requirements.Extra Functional Requirements(), 
                category = 'configs', 
                type = 'stack_application_template'
            )
        else :
            return StackApplicationTemplate(
                name = '0',
                services = [
                    '0'
                    ],
        )

    def testStackApplicationTemplate(self):
        """Test StackApplicationTemplate"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
