# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stackl_client.configuration import Configuration


class StackInstanceInvocation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'params': 'object',
        'tags': 'dict(str, str)',
        'stack_infrastructure_template': 'str',
        'stack_application_template': 'str',
        'stack_instance_name': 'str',
        'secrets': 'object',
        'replicas': 'dict(str, int)'
    }

    attribute_map = {
        'params': 'params',
        'tags': 'tags',
        'stack_infrastructure_template': 'stack_infrastructure_template',
        'stack_application_template': 'stack_application_template',
        'stack_instance_name': 'stack_instance_name',
        'secrets': 'secrets',
        'replicas': 'replicas'
    }

    def __init__(self, params=None, tags=None, stack_infrastructure_template='stackl', stack_application_template='web', stack_instance_name='default_test_instance', secrets=None, replicas=None, local_vars_configuration=None):  # noqa: E501
        """StackInstanceInvocation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._params = None
        self._tags = None
        self._stack_infrastructure_template = None
        self._stack_application_template = None
        self._stack_instance_name = None
        self._secrets = None
        self._replicas = None
        self.discriminator = None

        if params is not None:
            self.params = params
        if tags is not None:
            self.tags = tags
        if stack_infrastructure_template is not None:
            self.stack_infrastructure_template = stack_infrastructure_template
        if stack_application_template is not None:
            self.stack_application_template = stack_application_template
        if stack_instance_name is not None:
            self.stack_instance_name = stack_instance_name
        if secrets is not None:
            self.secrets = secrets
        if replicas is not None:
            self.replicas = replicas

    @property
    def params(self):
        """Gets the params of this StackInstanceInvocation.  # noqa: E501


        :return: The params of this StackInstanceInvocation.  # noqa: E501
        :rtype: object
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this StackInstanceInvocation.


        :param params: The params of this StackInstanceInvocation.  # noqa: E501
        :type: object
        """

        self._params = params

    @property
    def tags(self):
        """Gets the tags of this StackInstanceInvocation.  # noqa: E501


        :return: The tags of this StackInstanceInvocation.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this StackInstanceInvocation.


        :param tags: The tags of this StackInstanceInvocation.  # noqa: E501
        :type: dict(str, str)
        """

        self._tags = tags

    @property
    def stack_infrastructure_template(self):
        """Gets the stack_infrastructure_template of this StackInstanceInvocation.  # noqa: E501


        :return: The stack_infrastructure_template of this StackInstanceInvocation.  # noqa: E501
        :rtype: str
        """
        return self._stack_infrastructure_template

    @stack_infrastructure_template.setter
    def stack_infrastructure_template(self, stack_infrastructure_template):
        """Sets the stack_infrastructure_template of this StackInstanceInvocation.


        :param stack_infrastructure_template: The stack_infrastructure_template of this StackInstanceInvocation.  # noqa: E501
        :type: str
        """

        self._stack_infrastructure_template = stack_infrastructure_template

    @property
    def stack_application_template(self):
        """Gets the stack_application_template of this StackInstanceInvocation.  # noqa: E501


        :return: The stack_application_template of this StackInstanceInvocation.  # noqa: E501
        :rtype: str
        """
        return self._stack_application_template

    @stack_application_template.setter
    def stack_application_template(self, stack_application_template):
        """Sets the stack_application_template of this StackInstanceInvocation.


        :param stack_application_template: The stack_application_template of this StackInstanceInvocation.  # noqa: E501
        :type: str
        """

        self._stack_application_template = stack_application_template

    @property
    def stack_instance_name(self):
        """Gets the stack_instance_name of this StackInstanceInvocation.  # noqa: E501


        :return: The stack_instance_name of this StackInstanceInvocation.  # noqa: E501
        :rtype: str
        """
        return self._stack_instance_name

    @stack_instance_name.setter
    def stack_instance_name(self, stack_instance_name):
        """Sets the stack_instance_name of this StackInstanceInvocation.


        :param stack_instance_name: The stack_instance_name of this StackInstanceInvocation.  # noqa: E501
        :type: str
        """

        self._stack_instance_name = stack_instance_name

    @property
    def secrets(self):
        """Gets the secrets of this StackInstanceInvocation.  # noqa: E501


        :return: The secrets of this StackInstanceInvocation.  # noqa: E501
        :rtype: object
        """
        return self._secrets

    @secrets.setter
    def secrets(self, secrets):
        """Sets the secrets of this StackInstanceInvocation.


        :param secrets: The secrets of this StackInstanceInvocation.  # noqa: E501
        :type: object
        """

        self._secrets = secrets

    @property
    def replicas(self):
        """Gets the replicas of this StackInstanceInvocation.  # noqa: E501


        :return: The replicas of this StackInstanceInvocation.  # noqa: E501
        :rtype: dict(str, int)
        """
        return self._replicas

    @replicas.setter
    def replicas(self, replicas):
        """Sets the replicas of this StackInstanceInvocation.


        :param replicas: The replicas of this StackInstanceInvocation.  # noqa: E501
        :type: dict(str, int)
        """

        self._replicas = replicas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StackInstanceInvocation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StackInstanceInvocation):
            return True

        return self.to_dict() != other.to_dict()
