# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.configurator_api import ConfiguratorApi  # noqa: E501
from stackl_client.rest import ApiException


class TestConfiguratorApi(unittest.TestCase):
    """ConfiguratorApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.configurator_api.ConfiguratorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_configurator_file(self):
        """Test case for delete_configurator_file

        Delete Configurator File  # noqa: E501
        """
        pass

    def test_get_configurator_file(self):
        """Test case for get_configurator_file

        Get Configurator File  # noqa: E501
        """
        pass

    def test_post_configurator_file(self):
        """Test case for post_configurator_file

        Post Configurator File  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
