# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.services_api import ServicesApi  # noqa: E501
from stackl_client.rest import ApiException


class TestServicesApi(unittest.TestCase):
    """ServicesApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.services_api.ServicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_service(self):
        """Test case for delete_service

        Delete Service  # noqa: E501
        """
        pass

    def test_get_service_by_name(self):
        """Test case for get_service_by_name

        Get Service By Name  # noqa: E501
        """
        pass

    def test_get_services(self):
        """Test case for get_services

        Get Services  # noqa: E501
        """
        pass

    def test_post_service(self):
        """Test case for post_service

        Post Service  # noqa: E501
        """
        pass

    def test_put_service(self):
        """Test case for put_service

        Put Service  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
