# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.terraform_api import TerraformApi  # noqa: E501
from stackl_client.rest import ApiException


class TestTerraformApi(unittest.TestCase):
    """TerraformApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.terraform_api.TerraformApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_terraform_statefile(self):
        """Test case for delete_terraform_statefile

        Delete Terraform Statefile  # noqa: E501
        """
        pass

    def test_get_terraform_statefile(self):
        """Test case for get_terraform_statefile

        Get Terraform Statefile  # noqa: E501
        """
        pass

    def test_post_terraform_statefile(self):
        """Test case for post_terraform_statefile

        Post Terraform Statefile  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
