# coding: utf-8

"""
    STACKL

    stackl  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import stackl_client
from stackl_client.models.stack_instance_status import StackInstanceStatus  # noqa: E501
from stackl_client.rest import ApiException

class TestStackInstanceStatus(unittest.TestCase):
    """StackInstanceStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StackInstanceStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = stackl_client.models.stack_instance_status.StackInstanceStatus()  # noqa: E501
        if include_optional :
            return StackInstanceStatus(
                functional_requirement = '0', 
                infrastructure_target = '0', 
                service = '0', 
                status = [
                    0
                    ], 
                error_message = '0'
            )
        else :
            return StackInstanceStatus(
        )

    def testStackInstanceStatus(self):
        """Test StackInstanceStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
