# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import stackl_client
from stackl_client.api.documents_api import DocumentsApi  # noqa: E501
from stackl_client.rest import ApiException


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    def setUp(self):
        self.api = stackl_client.api.documents_api.DocumentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_document(self):
        """Test case for delete_document

        Delete Document  # noqa: E501
        """
        pass

    def test_get_document_by_type_and_name(self):
        """Test case for get_document_by_type_and_name

        Get Document By Type And Name  # noqa: E501
        """
        pass

    def test_get_documents_by_type(self):
        """Test case for get_documents_by_type

        Get Documents By Type  # noqa: E501
        """
        pass

    def test_get_types(self):
        """Test case for get_types

        Get Types  # noqa: E501
        """
        pass

    def test_post_document(self):
        """Test case for post_document

        Post Document  # noqa: E501
        """
        pass

    def test_put_document(self):
        """Test case for put_document

        Put Document  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
