# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import stackl_client
from stackl_client.models.stack_instance_service import StackInstanceService  # noqa: E501
from stackl_client.rest import ApiException

class TestStackInstanceService(unittest.TestCase):
    """StackInstanceService unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StackInstanceService
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = stackl_client.models.stack_instance_service.StackInstanceService()  # noqa: E501
        if include_optional :
            return StackInstanceService(
                infrastructure_target = '0', 
                provisioning_parameters = stackl_client.models.provisioning_parameters.Provisioning Parameters(), 
                status = [
                    stackl_client.models.functional_requirement_status.FunctionalRequirementStatus(
                        functional_requirement = '0', 
                        status = 1, 
                        error_message = '0', )
                    ]
            )
        else :
            return StackInstanceService(
        )

    def testStackInstanceService(self):
        """Test StackInstanceService"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
