# coding: utf-8

"""
    FastAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import stackl_client
from stackl_client.models.base_document import BaseDocument  # noqa: E501
from stackl_client.rest import ApiException

class TestBaseDocument(unittest.TestCase):
    """BaseDocument unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BaseDocument
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = stackl_client.models.base_document.BaseDocument()  # noqa: E501
        if include_optional :
            return BaseDocument(
                name = '0', 
                category = '0', 
                type = '0', 
                params = stackl_client.models.params.Params(), 
                description = 'Base Document'
            )
        else :
            return BaseDocument(
                name = '0',
                category = '0',
                type = '0',
        )

    def testBaseDocument(self):
        """Test BaseDocument"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
